cheesecake.cheesecake_index.Step

Package cheesecake :: Module cheesecake_index :: Class Step |
[hide private]
[frames] | no frames]

## Class Step
source code

    object --+
             |
            Step

Known Subclasses:
  StepByVariable

Single step during computation of package score.

Instance Methods | [hide private]
| __init__(self, provides) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| decide(self, cheesecake) Decide if step should be run.
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, provides) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### decide(self, cheesecake) | source code
Decide if step should be run. It checks if there's at least one index from current profile that need variables provided by this step. Override this method for other behaviour.